# Takao

Takao is a dark theme for Sphinx I created for use in my own projects.

## Installation

1. Install the Python package:

   ```shell
   pip install takao
   ```

2. Update `html_theme` in your Sphinx project configuration:

   ```python
   html_theme = "takao"
   ```

3. Create a fresh documentation build in your Sphinx project directory:

   ```shell
   make clean
   make html
   ```
